#include "global.h"

#pragma config UPLLEN   = ON            // USB PLL Enabled
#pragma config FPLLMUL  = MUL_20        // PLL Multiplier
#pragma config UPLLIDIV = DIV_2         // USB PLL Input Divider
#pragma config FPLLIDIV = DIV_2         // PLL Input Divider
#pragma config FPLLODIV = DIV_1         // PLL Output Divider
#pragma config FPBDIV   = DIV_1         // Peripheral Clock divisor
#pragma config FWDTEN   = OFF           // Watchdog Timer
#pragma config WDTPS    = PS1           // Watchdog Timer Postscale
#pragma config FCKSM    = CSDCMD        // Clock Switching & Fail Safe Clock Monitor
#pragma config OSCIOFNC = OFF           // CLKO Enable
#pragma config POSCMOD  = HS            // Primary Oscillator
#pragma config IESO     = OFF           // Internal/External Switch-over
#pragma config FSOSCEN  = OFF           // Secondary Oscillator Enable (KLO was off)
#pragma config FNOSC    = PRIPLL        // Oscillator Selection
#pragma config CP       = OFF           // Code Protect
#pragma config BWP      = ON            // Boot Flash Write Protect
#pragma config PWP      = OFF           // Program Flash Write Protect
#pragma config ICESEL   = ICS_PGx1      // ICE/ICD Comm Channel Select
#pragma config DEBUG    = OFF           // Background Debugger Enable#else

BOOL InitializeSystem ( void )
{
	SYSTEMConfigPerformance(GetSystemClock());
	INTEnableSystemMultiVectoredInt(); // Interrupt vectoring

	/* Start Timer1 in interval time of 1ms */
	OpenTimer1( T1_ON | T1_PS_1_256 | T1_SOURCE_INT,GetPeripheralClock()/256/1000);
	PR1 = GetPeripheralClock()/256/1000-1;
	mT1SetIntPriority(5);
	mT1ClearIntFlag();
	mT1IntEnable(1);

	AD1PCFG=0x1FFF;

	led1_setup();
	led2_setup();
	led1_off();
	led2_off();

    return TRUE;
}

FATFS	Fatfs;			/* File system object */
extern volatile UINT Timer;	/* 1kHz increment timer */
BYTE	dummybuf[32768];

void main(void)
{
	FIL		fil;
	FRESULT	fres;
	UINT	start_r,end_r;
	UINT	start_w,end_w;
	UINT	i,bw;

	InitializeSystem();
	f_mount(0, &Fatfs);

	//݃ptH[}Xv
	fres=f_open(&fil,"DUMMY.BIN",
		FA_WRITE | FA_CREATE_ALWAYS);
	if(fres==FR_OK){
		start_w=Timer;
		for(i=0;i<1000;i++){
			f_write(&fil,dummybuf,sizeof(dummybuf),&bw);
		}
		end_w=Timer;
		f_close(&fil);
	}

	//ǂݍ݃ptH[}Xv
	fres=f_open(&fil,"DUMMY.BIN",FA_READ);
	if(fres==FR_OK){
		start_r=Timer;
		for(i=0;i<1000;i++){
			f_read(&fil,dummybuf,sizeof(dummybuf),&bw);
		}
		end_r=Timer;
		f_close(&fil);
	}
	f_unlink("DUMMY.BIN");

	//ʏ
	fres=f_open(&fil,"RESULT.TXT",
		FA_WRITE | FA_CREATE_ALWAYS);
	if(fres==FR_OK){
		f_printf(&fil,"write %lu KBytes/s\r\n",
			(sizeof(dummybuf)*1000)/(end_w-start_w));
		f_printf(&fil,"read  %lu KBytes/s\r\n",
			(sizeof(dummybuf)*1000)/(end_r-start_r));
		f_close(&fil);
	}

	for(;;){
		led1_on();
		DelayMs(1000);
		led1_off();
		led2_on();
		DelayMs(1000);
		led2_off();
	}
}
